@@ -11,8 +11,6 @@ from kornia import filters
 
 # helper functions
 
-def identity(x): return x
-
 def default(val, def_val):
     return def_val if val is None else val
 
@@ -71,8 +69,6 @@ def update_moving_average(ema_updater, ma_model, current_model):
 
 # MLP class for projector and predictor
 
-DEFAULT_PROJ_SIZE = 256
-
 class MLP(nn.Module):
     def __init__(self, dim, projection_size, hidden_size = 4096):
         super().__init__()
@@ -126,7 +122,7 @@ class NetWrapper(nn.Module):
         projector = MLP(dim, self.projection_size, self.projection_hidden_size)
         return projector.to(hidden)
 
-    def forward(self, x):
+    def get_representation(self, x):
         if self.layer == -1:
             return self.net(x)
 
@@ -134,9 +130,12 @@ class NetWrapper(nn.Module):
         hidden = self.hidden
         self.hidden = None
         assert hidden is not None, f'hidden layer {self.layer} never emitted an output'
+        return hidden
 
-        projector = self._get_projector(hidden)
-        projection = projector(hidden)
+    def forward(self, x):
+        representation = self.get_representation(x)
+        projector = self._get_projector(representation)
+        projection = projector(representation)
         return projection
 
 # main class
@@ -178,11 +177,9 @@ class BYOL(nn.Module):
 
     def update_moving_average(self):
         assert self.target_encoder is not None, 'target encoder has not been created yet'
-        self.target_encoder = update_moving_average(self.target_ema_updater, self.target_encoder, self.online_encoder)
+        update_moving_average(self.target_ema_updater, self.target_encoder, self.online_encoder)
 
     def forward(self, x):
-        b, c, h, w, device = *x.shape, x.device
-
         image_one, image_two = self.augment(x), self.augment(x)
 
         online_proj_one = self.online_encoder(image_one)
@@ -191,9 +188,10 @@ class BYOL(nn.Module):
         online_pred_one = self.online_predictor(online_proj_one)
         online_pred_two = self.online_predictor(online_proj_two)
 
-        target_encoder = self._get_target_encoder()
-        target_proj_one = target_encoder(image_one)
-        target_proj_two = target_encoder(image_two)
+        with torch.no_grad():
+            target_encoder = self._get_target_encoder()
+            target_proj_one = target_encoder(image_one)
+            target_proj_two = target_encoder(image_two)
 
         loss_one = loss_fn(online_pred_one, target_proj_two.detach())
         loss_two = loss_fn(online_pred_two, target_proj_one.detach())
